@@ -63,12 +63,13 @@ extern int keyerport;
 extern char synclogfile[];
 extern int sc_sidetone;
 extern char sc_volume[];
+extern int cwstart;
 
 char  parameterstring[20];
-char parameters[50][19];
+char parameters[51][19];
 char cmdstring[80];
 int i, k, x, nopar  = 0;
-int maxpar  = 49;
+int maxpar  = 50;
 int volumebuffer;
 int currentmode = 0;
 
@@ -123,6 +124,7 @@ strcpy(parameters[46],  "MINITERM");
 strcpy(parameters[47],  "RTTY");
 strcpy(parameters[48], "SOUND");
 strcpy(parameters[49],  "CWMODE");
+strcpy(parameters[50],  "CHARS");
 
 	nopar = 0;
 	
@@ -518,7 +520,7 @@ strcpy(parameters[49],  "CWMODE");
 						mvprintw(24,0, "keyer not active; switching to SSB");
 						trxmode = SSBMODE;
 						clear_display();
-					}
+					}				
 				}
 
 			}
@@ -716,7 +718,18 @@ strcpy(parameters[49],  "CWMODE");
 			clear_display();
 			break;
 		}
-
+		case 50:
+		{
+			mvprintw(13, 29, "? Characters: (0...4)");
+			refresh();
+			x = onechar();
+			if ((x - 48) < 5 && (x - 48) >= 1)
+				cwstart = x - 48;
+			if ( (x-48) == 0) cwstart = 0;
+			
+			break;
+				
+		}
 		default:
 		{
 		
