@@ -26,6 +26,8 @@
 #	include <config.h>
 #endif
 
+static char searchresult[MAX_CALLS][82];
+static char result[MAX_CALLS][82];
 
  	int searchlog(char *searchstring)
 
@@ -75,9 +77,9 @@
     extern int itumult;
 
 
-char searchresult[MAX_CALLS][82];
+//char searchresult[MAX_CALLS][82];
 int srch_index=0;
-char result[MAX_CALLS][82];
+//char result[MAX_CALLS][82];
 int r_index=0;
 char s_inputbuffer[82] =  "";
 char s_inputbuffercpy[82] =  "";
@@ -91,12 +93,13 @@ char *tmpstr;
 
 char callmaster_location[80];
 
-	if (strlen(s_inputbuffer)>=83)
+#if 0
+		if (strlen(s_inputbuffer)>=83)
 	{
 		printf ("WARNING: Input buffer is longer than 82 characters! exiting...");
 		exit(1);
 	}
-
+#endif
 	strcpy(callmaster_location, PACKAGE_DATA_DIR) ;
 	strcat(callmaster_location, "/callmaster ") ;
 
