@@ -50,11 +50,14 @@ extern struct tln_logline *loghead;
 extern struct tln_logline *logtail;
 extern struct tln_logline *temp;
 extern struct tln_logline *viewing;
-extern char spot_ptr[100][82];
-extern char lastmsg[80];
+extern char spot_ptr[MAX_SPOTS][82];
+extern char lastmsg[];
 extern int ptr;
+extern int clusterlog;
 
 int len;
+FILE *fp;
+
 
 	for (len = 0; len < strlen(s); len += 80)    {
 
@@ -63,6 +66,21 @@ int len;
  			lastmsg[0] = '\0';
 			strncat(lastmsg, spot_ptr[ptr],79);
 		}
+		
+		if (clusterlog == 1) {
+		if  ( (fp = fopen("clusterlog","a"))  == NULL){
+					mvprintw(24,0,  "Opening clusterlog not possible.");
+		}
+		else{
+			if (strlen(lastmsg) > 20) {
+				fputs( lastmsg, fp);
+				fputs("\n", fp);	
+			}
+
+			fclose(fp);
+		}
+
+		}
 		ptr++;
 
 		if (ptr > 99) {
@@ -723,7 +741,7 @@ extern char pr_hostaddress[16];
 extern SCREEN *packetscreen;
 extern WINDOW *sclwin;
 extern WINDOW *entwin;
-extern char spot_ptr[100][80];
+extern char spot_ptr[MAX_SPOTS][82];
 extern int tncport;
 extern int fdSertnc;
 extern int fdFIFO;
